using System;
using System.Threading;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using dotnetCHARTING.WinForms;

namespace RateAllocation
{
	/// <summary>
	/// The Main form of the application
	/// </summary>
	public class MainForm : System.Windows.Forms.Form
	{
		#region properties

		// windows controls
		private System.Windows.Forms.Timer Ticker;
		private System.ComponentModel.IContainer components;
		private System.Windows.Forms.TabControl tabControl1;
		private System.Windows.Forms.TabPage tabPage1;
		private System.Windows.Forms.TabPage tabPage2;		
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Label label9;
		private System.Windows.Forms.TextBox txtCallDuration;
		private System.Windows.Forms.CheckBox chbIO;
		private System.Windows.Forms.Label label8;
		private System.Windows.Forms.Label label7;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox txtNodeCapacity;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.TextBox txtConcurrentCalls;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.TextBox txtTotalConnections;
		private System.Windows.Forms.Label lblTotalCalls;
		private System.Windows.Forms.Label lblAverage;
		private System.Windows.Forms.ComboBox cmbSpeed;
		private System.Windows.Forms.ComboBox cmbAlgorithm;
		private System.Windows.Forms.Button btnStart;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.Windows.Forms.Button btnGenerate;
		private System.Windows.Forms.Label label10;
		private System.Windows.Forms.Label FailedCalls;
		private System.Windows.Forms.CheckBox chbReturnUponConnection;
		private System.Windows.Forms.Label label11;
		private System.Windows.Forms.CheckedListBox lbNodes;
		private System.Windows.Forms.Label label12;
		private System.Windows.Forms.Button btnResetPHTables;
        private System.Windows.Forms.OpenFileDialog openFileDialog1;
        private System.Windows.Forms.PictureBox pictureBox2;
		private System.Windows.Forms.CheckBox chbLoopRemoval;

        // the charting object
		// the custom draw panel
		private RateAllocation.DrawPanel pnlGraph;
		// total time for this simulation
		private double totaltime=0;
		// the current simultation
		private Simulation sim;
		// number of completed calls 
		private double complete=0;
		// number of failed calls 
        private double failed = 0;
        private Chart TheChart;
        private PictureBox pictureBox1;
        private Panel panel2;
        private System.Windows.Forms.Label label13;
		// if antnet was actuavated on the last iteration (used for labelling charts)
		private bool AntNetOnLastIteration=true;

		#endregion
	
		[STAThread]
		static void Main() 
		{
			Application.Run(new MainForm());
		}

	
		public MainForm()
		{
			
			InitializeComponent();
		
			cmbSpeed.SelectedIndex=5;
			
			cmbAlgorithm.SelectedIndex=0;

			lbNodes.Items.AddRange(Global.Nodes);
			
			for(int i=0;i<lbNodes.Items.Count;i++)
				lbNodes.SetItemChecked(i,true);

			
			this.lbNodes.ItemCheck += new ItemCheckEventHandler(this.lbNodes_OnClick);	
		}


		
		private void btnStart_Click(object sender, System.EventArgs e)
		{
			
			Ticker.Stop();

			#region textbox input validation

			// set the timer speed
			if(cmbSpeed.SelectedIndex==0)
                Ticker.Interval = 1000;
			else if(cmbSpeed.SelectedIndex==1)
				Ticker.Interval = 200;
			else if(cmbSpeed.SelectedIndex==2)
				Ticker.Interval = 200;
			else if(cmbSpeed.SelectedIndex==3)
				Ticker.Interval = 50;
			else if(cmbSpeed.SelectedIndex==4)
					 Ticker.Interval = 10;
			else if(cmbSpeed.SelectedIndex==5)
					 Ticker.Interval = 1;

			try
			{
				Global.MaxConcurrentCalls = Int32.Parse(txtConcurrentCalls.Text);
			}
			catch
			{
				MessageBox.Show("Maximum Concurrent Calls textbox has an invalid input");
				txtConcurrentCalls.Focus();
				txtConcurrentCalls.Text = "";
				return;
			}

			try
			{
				Global.TotalCalls = Int32.Parse(txtTotalConnections.Text);
			}
			catch
			{
				MessageBox.Show("Total number of Calls textbox has an invalid input", "invalid input" ,MessageBoxButtons.OK,MessageBoxIcon.Warning);
				txtTotalConnections.Focus();
				txtTotalConnections.Text = "";
				return;
			}

			try
			{
				Global.NodeCapacity = Int32.Parse(txtNodeCapacity.Text);
			}
			catch
			{
				MessageBox.Show("Total number of Calls textbox has an invalid input", "invalid input", MessageBoxButtons.OK,MessageBoxIcon.Warning);
				txtNodeCapacity.Focus();
				txtNodeCapacity.Text = "";
				return;
			}

			try
			{
				Global.CallDuration = Int32.Parse(txtCallDuration.Text);
			}
			catch
			{
				MessageBox.Show("Call duration textbox has an invalid input", "invalid input", MessageBoxButtons.OK,MessageBoxIcon.Warning);
				txtCallDuration.Focus();
				txtCallDuration.Text = "";
				return;
			}

			#endregion
	
			
			sim = new Simulation();

			
			complete=0;
			failed=0;		
			totaltime=0;
			
	
			Global.Simulations.Add(sim);

			
			Global.Calls.Clear();
	
			Global.TotalCallsMade=0;
		
			
			lblAverage.Text = "";
			lblTotalCalls.Text = "";

			
			Global.TerminateAllCalls();

			Ticker.Start();

			
			btnStart.Enabled=false;
		}


		

		private void Ticker_Tick(object sender, System.EventArgs e)
		{
			Call c;

			if(Global.TotalCallsMade>=Global.TotalCalls)
			{
				
				btnStart.Enabled=true;	
				
				Ticker.Stop();
			}

			
			if(Global.MaxConcurrentCalls>Global.Calls.Count)
			{
				
				Random r1 = new Random(Global.Seed);
				Random r2 = new Random(Global.Seed);
			
				
				Global.Calls.Add(new Call(r1.Next(0,29), r2.Next(0,29)));
			}
           
			
			for(int i=0;i<Global.Calls.Count;i++)
			{
				
				c = (Call)Global.Calls[i];

			
				if(c.Duration!=0 && !c.HasFailed )
				{
					
					if(c.AntDirection == eAntDirection.BackwardAnt)
					{
						
						if(c.NewValue==-1)
						{
						
							double total = Global.CallDuration;
							
							double vnodes = c.VisitedNodes.Count-1;
							c.NewValue = ((1/(vnodes/total))/total)*100;
						}

						if(c.VisitedNodes.Count>0)
						{
							if(c.finalVisitedNodeCount==0)
								c.finalVisitedNodeCount=c.VisitedNodes.Count;

						
							Node endNode = Global.Nodes[(int)c.VisitedNodes[c.VisitedNodes.Count-1]];
							
							c.FinalVisitedNodes.Add(endNode);
							
							
							c.VisitedNodes.RemoveAt(c.VisitedNodes.Count-1);

							Node tNode;

							int LinkedConnID=-1;

							if(c.VisitedNodes.Count>0)
								LinkedConnID = (int)c.VisitedNodes[c.VisitedNodes.Count-1];

							
							for(int j=c.VisitedNodes.Count-1;j>=0;j--)
							{
								
								tNode = Global.Nodes[((int)c.VisitedNodes[j])];

								
								PheromoneTable p = endNode.GetPheromoneTableForNode(tNode.ID);

								if(p!=null)
								{
									
									if(cmbAlgorithm.SelectedIndex==0)
									{
										p.UpdateProbabilities(c.NewValue, LinkedConnID);

										
										if(!AntNetOnLastIteration)
										{
											sim.AnnoText[sim.AnnoText.Count-1]="Activated";
											AntNetOnLastIteration=true;
										}
									}
									else
									{
										
										if(AntNetOnLastIteration)
										{
											sim.AnnoText[sim.AnnoText.Count-1]="Deactivated";
											AntNetOnLastIteration=false;
										}
									}
								}

								LinkedConnID = tNode.ID;
							}

							if(c.VisitedNodes.Count==0 && chbReturnUponConnection.Checked)
								c.Finished=true;
						}
					}

				
					if(c.AntDirection == eAntDirection.ForwardAnt)
					{
						
						int nodeid = c.ConnectNextNode();

						
						if(nodeid==-1)
						{				
							c.waitTime++;
						}
						else if(Node.Connect(nodeid, c.CallID, c.DestinationNodeID))
						{
						
							c.CurrentNodeID = nodeid;
                            
                            c.VisitedNodes.Add(nodeid);
						}

					
						if(nodeid==c.DestinationNodeID)
						{
							c.Successful=true;
						
							if(chbLoopRemoval.Checked)
								c.LoopRemoval();

							
							c.AntDirection = eAntDirection.BackwardAnt;
						}
					}

				
					c.Duration--;	
				}
			
				
				if(c.Duration==0 || c.Finished)
				{
					
					if (c.Successful)
					{
                        complete++;
						
						totaltime += c.finalVisitedNodeCount;
			
						double ave = totaltime / complete;
						this.lblAverage.Text = ave.ToString();
					}
					else
					{
						
						FailedCalls.Text = ((int)++failed).ToString();
					}

				
					this.lblTotalCalls.Text = (++Global.TotalCallsMade).ToString();

					
					c.TerminateCall();

				
					sim.Calls.Add(c);

					
					sim.AnnoText.Add("");
			
					int util=0;
					
					for(int k=0;k<Global.Nodes.Length;k++)
						util+=Global.Nodes[k].CallIDS.Count;

					sim.NetworkUtilisation.Add(util);

				
					Global.Calls.Remove(c);	

					
					i--;												
				}
			}

			if(!chbIO.Checked)
				pnlGraph.Refresh();
		}


	
		private void btnGenerate_Click(object sender, System.EventArgs e)
		{
			GenerateGraph();
		}


		// generates a graph from the simulations
		public void GenerateGraph()
		{
		
			TheChart.SeriesCollection.Clear();

			
			TheChart.Title = "Average connection time";
			TheChart.Type = ChartType.Scatter;
			TheChart.Use3D = false;	
			TheChart.DefaultSeries.DefaultElement.Transparency = 20;
			TheChart.DefaultSeries.DefaultElement.Marker.Type = ElementMarkerType.None;
			TheChart.ChartArea.LegendBox.Template = "%Name%Icon";
			TheChart.DefaultSeries.Line.Width = 2;

		
			TheChart.SeriesCollection.Add(GenerateChartData());		
			
			
			TheChart.RefreshChart();
		}


		
		public SeriesCollection GenerateChartData()
		{
			
			SeriesCollection SC = new SeriesCollection();

			Simulation s;

			
			for(int i=0;i<Global.Simulations.Count;i++)
			{
				double ave=0;
				double TotalHops=0;

			
				s = (Simulation)Global.Simulations[i];

			
				Series series = new Series();

				
				series.Name = "Simulation "+((int)i+1).ToString();

				Call c;
			
				for(int j=0;j<s.Calls.Count;j++)
				{
					
					c = (Call)s.Calls[j];
					TotalHops += c.FinalVisitedNodes.Count;
					ave = Convert.ToDouble(TotalHops) / Convert.ToDouble(j+1);

					Element e = new Element();
					
					
					if(s.AnnoText[j].ToString()!="")
					{
						Annotation anno = new Annotation(s.AnnoText[j].ToString()); 
						anno.DefaultCorner = BoxCorner.Round;
						anno.Orientation = dotnetCHARTING.WinForms.Orientation.TopRight;
						e.Annotation = anno;
					}
					
				
					e.YValue = ave;
					e.XValue = j+1;
					
					series.Elements.Add(e);
				}

			
				SC.Add(series);
			}

		
			for(int i=0;i<SC.Count;i++)
			{
				if(i==0)
					SC[0].DefaultElement.Color = Color.FromArgb(255,99,49);
				if(i==1)
					SC[1].DefaultElement.Color = Color.FromArgb(0,156,255);
				if(i==2)
					SC[2].DefaultElement.Color = Color.FromArgb(49,255,49);
				if(i==3)
					SC[3].DefaultElement.Color = Color.FromArgb(255,255,0);
			}

			return SC;
		}



		private void lbNodes_OnClick(object sender, ItemCheckEventArgs e)
		{
			
			if(e.CurrentValue==CheckState.Checked)
			{
				
				Global.Nodes[lbNodes.SelectedIndex].DontRouteTraffic=true;
			
				sim.AnnoText[sim.AnnoText.Count-1] = "Node "+lbNodes.SelectedIndex.ToString()+" Routing Off";
			}
			else if(e.CurrentValue==CheckState.Unchecked)
			{
				
				Global.Nodes[lbNodes.SelectedIndex].DontRouteTraffic=false;
		
				sim.AnnoText[sim.AnnoText.Count-1] = "Node "+lbNodes.SelectedIndex.ToString()+" Routing On";
			}
		}


	
		private void btnResetPHTables_Click(object sender, System.EventArgs e)
		{
			Node n;

			
			for(int i=0;i<Global.Nodes.Length;i++)
			{
				n = Global.Nodes[i];
				
				n.GenerateDefaultPheromoneTables();
			}
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.components = new System.ComponentModel.Container();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(MainForm));
            dotnetCHARTING.WinForms.ChartArea chartArea1 = new dotnetCHARTING.WinForms.ChartArea();
            dotnetCHARTING.WinForms.Background background1 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Element element1 = new dotnetCHARTING.WinForms.Element();
            dotnetCHARTING.WinForms.SubValue subValue1 = new dotnetCHARTING.WinForms.SubValue();
            dotnetCHARTING.WinForms.Line line1 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Hotspot hotspot1 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.LegendEntry legendEntry1 = new dotnetCHARTING.WinForms.LegendEntry();
            dotnetCHARTING.WinForms.Background background2 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Line line2 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Hotspot hotspot2 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Line line3 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Label label14 = new dotnetCHARTING.WinForms.Label();
            dotnetCHARTING.WinForms.Hotspot hotspot3 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Truncation truncation1 = new dotnetCHARTING.WinForms.Truncation();
            dotnetCHARTING.WinForms.LegendBox legendBox1 = new dotnetCHARTING.WinForms.LegendBox();
            dotnetCHARTING.WinForms.Background background3 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.LegendEntry legendEntry2 = new dotnetCHARTING.WinForms.LegendEntry();
            dotnetCHARTING.WinForms.Background background4 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Line line4 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Hotspot hotspot4 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Label label15 = new dotnetCHARTING.WinForms.Label();
            dotnetCHARTING.WinForms.Hotspot hotspot5 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Truncation truncation2 = new dotnetCHARTING.WinForms.Truncation();
            dotnetCHARTING.WinForms.LegendEntry legendEntry3 = new dotnetCHARTING.WinForms.LegendEntry();
            dotnetCHARTING.WinForms.Background background5 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Line line5 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Hotspot hotspot6 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Line line6 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Line line7 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Shadow shadow1 = new dotnetCHARTING.WinForms.Shadow();
            dotnetCHARTING.WinForms.Line line8 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Shadow shadow2 = new dotnetCHARTING.WinForms.Shadow();
            dotnetCHARTING.WinForms.Box box1 = new dotnetCHARTING.WinForms.Box();
            dotnetCHARTING.WinForms.Background background6 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Line line9 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Label label16 = new dotnetCHARTING.WinForms.Label();
            dotnetCHARTING.WinForms.Hotspot hotspot7 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Truncation truncation3 = new dotnetCHARTING.WinForms.Truncation();
            dotnetCHARTING.WinForms.Line line10 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Shadow shadow3 = new dotnetCHARTING.WinForms.Shadow();
            dotnetCHARTING.WinForms.Axis axis1 = new dotnetCHARTING.WinForms.Axis();
            dotnetCHARTING.WinForms.AxisTick axisTick1 = new dotnetCHARTING.WinForms.AxisTick();
            dotnetCHARTING.WinForms.Line line11 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Line line12 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.ScaleRange scaleRange1 = new dotnetCHARTING.WinForms.ScaleRange();
            dotnetCHARTING.WinForms.Line line13 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.AxisTick axisTick2 = new dotnetCHARTING.WinForms.AxisTick();
            dotnetCHARTING.WinForms.Line line14 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Line line15 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Element element2 = new dotnetCHARTING.WinForms.Element();
            dotnetCHARTING.WinForms.SubValue subValue2 = new dotnetCHARTING.WinForms.SubValue();
            dotnetCHARTING.WinForms.Line line16 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Hotspot hotspot8 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.LegendEntry legendEntry4 = new dotnetCHARTING.WinForms.LegendEntry();
            dotnetCHARTING.WinForms.Background background7 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Line line17 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Hotspot hotspot9 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.SmartLabel smartLabel1 = new dotnetCHARTING.WinForms.SmartLabel();
            dotnetCHARTING.WinForms.Hotspot hotspot10 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Line line18 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Truncation truncation4 = new dotnetCHARTING.WinForms.Truncation();
            dotnetCHARTING.WinForms.Shadow shadow4 = new dotnetCHARTING.WinForms.Shadow();
            dotnetCHARTING.WinForms.Background background8 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Label label17 = new dotnetCHARTING.WinForms.Label();
            dotnetCHARTING.WinForms.Hotspot hotspot11 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Truncation truncation5 = new dotnetCHARTING.WinForms.Truncation();
            dotnetCHARTING.WinForms.Line line19 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.ElementMarker elementMarker1 = new dotnetCHARTING.WinForms.ElementMarker();
            dotnetCHARTING.WinForms.Hotspot hotspot12 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Truncation truncation6 = new dotnetCHARTING.WinForms.Truncation();
            dotnetCHARTING.WinForms.ChartArea chartArea2 = new dotnetCHARTING.WinForms.ChartArea();
            dotnetCHARTING.WinForms.Background background9 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Element element3 = new dotnetCHARTING.WinForms.Element();
            dotnetCHARTING.WinForms.SubValue subValue3 = new dotnetCHARTING.WinForms.SubValue();
            dotnetCHARTING.WinForms.Line line20 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Hotspot hotspot13 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.LegendEntry legendEntry5 = new dotnetCHARTING.WinForms.LegendEntry();
            dotnetCHARTING.WinForms.Background background10 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Line line21 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Hotspot hotspot14 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Line line22 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Label label18 = new dotnetCHARTING.WinForms.Label();
            dotnetCHARTING.WinForms.Hotspot hotspot15 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Truncation truncation7 = new dotnetCHARTING.WinForms.Truncation();
            dotnetCHARTING.WinForms.Line line23 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Shadow shadow5 = new dotnetCHARTING.WinForms.Shadow();
            dotnetCHARTING.WinForms.Box box2 = new dotnetCHARTING.WinForms.Box();
            dotnetCHARTING.WinForms.Background background11 = new dotnetCHARTING.WinForms.Background();
            dotnetCHARTING.WinForms.Line line24 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Label label19 = new dotnetCHARTING.WinForms.Label();
            dotnetCHARTING.WinForms.Hotspot hotspot16 = new dotnetCHARTING.WinForms.Hotspot();
            dotnetCHARTING.WinForms.Truncation truncation8 = new dotnetCHARTING.WinForms.Truncation();
            dotnetCHARTING.WinForms.Line line25 = new dotnetCHARTING.WinForms.Line();
            dotnetCHARTING.WinForms.Shadow shadow6 = new dotnetCHARTING.WinForms.Shadow();
            this.Ticker = new System.Windows.Forms.Timer(this.components);
            this.tabControl1 = new System.Windows.Forms.TabControl();
            this.tabPage1 = new System.Windows.Forms.TabPage();
            this.groupBox1 = new System.Windows.Forms.GroupBox();
            this.chbLoopRemoval = new System.Windows.Forms.CheckBox();
            this.btnResetPHTables = new System.Windows.Forms.Button();
            this.label12 = new System.Windows.Forms.Label();
            this.lbNodes = new System.Windows.Forms.CheckedListBox();
            this.chbReturnUponConnection = new System.Windows.Forms.CheckBox();
            this.label11 = new System.Windows.Forms.Label();
            this.label10 = new System.Windows.Forms.Label();
            this.FailedCalls = new System.Windows.Forms.Label();
            this.label9 = new System.Windows.Forms.Label();
            this.txtCallDuration = new System.Windows.Forms.TextBox();
            this.chbIO = new System.Windows.Forms.CheckBox();
            this.label8 = new System.Windows.Forms.Label();
            this.label7 = new System.Windows.Forms.Label();
            this.label6 = new System.Windows.Forms.Label();
            this.label5 = new System.Windows.Forms.Label();
            this.label4 = new System.Windows.Forms.Label();
            this.label3 = new System.Windows.Forms.Label();
            this.txtNodeCapacity = new System.Windows.Forms.TextBox();
            this.label2 = new System.Windows.Forms.Label();
            this.txtConcurrentCalls = new System.Windows.Forms.TextBox();
            this.label1 = new System.Windows.Forms.Label();
            this.txtTotalConnections = new System.Windows.Forms.TextBox();
            this.lblTotalCalls = new System.Windows.Forms.Label();
            this.lblAverage = new System.Windows.Forms.Label();
            this.cmbSpeed = new System.Windows.Forms.ComboBox();
            this.cmbAlgorithm = new System.Windows.Forms.ComboBox();
            this.btnStart = new System.Windows.Forms.Button();
            this.pnlGraph = new RateAllocation.DrawPanel();
            this.tabPage2 = new System.Windows.Forms.TabPage();
            this.pictureBox2 = new System.Windows.Forms.PictureBox();
            this.groupBox2 = new System.Windows.Forms.GroupBox();
            this.btnGenerate = new System.Windows.Forms.Button();
            this.TheChart = new dotnetCHARTING.WinForms.Chart();
            this.label13 = new System.Windows.Forms.Label();
            this.pictureBox1 = new System.Windows.Forms.PictureBox();
            this.panel2 = new System.Windows.Forms.Panel();
            this.openFileDialog1 = new System.Windows.Forms.OpenFileDialog();
            this.tabControl1.SuspendLayout();
            this.tabPage1.SuspendLayout();
            this.groupBox1.SuspendLayout();
            this.tabPage2.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox2)).BeginInit();
            this.groupBox2.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.TheChart)).BeginInit();
            this.TheChart.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox1)).BeginInit();
            this.SuspendLayout();
            // 
            // Ticker
            // 
            this.Ticker.Interval = 333;
            this.Ticker.Tick += new System.EventHandler(this.Ticker_Tick);
            // 
            // tabControl1
            // 
            this.tabControl1.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.tabControl1.Controls.Add(this.tabPage1);
            this.tabControl1.Controls.Add(this.tabPage2);
            this.tabControl1.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.tabControl1.Location = new System.Drawing.Point(4, 17);
            this.tabControl1.Name = "tabControl1";
            this.tabControl1.SelectedIndex = 0;
            this.tabControl1.Size = new System.Drawing.Size(1137, 849);
            this.tabControl1.TabIndex = 2;
            // 
            // tabPage1
            // 
            this.tabPage1.Controls.Add(this.groupBox1);
            this.tabPage1.Controls.Add(this.pnlGraph);
            this.tabPage1.Location = new System.Drawing.Point(4, 25);
            this.tabPage1.Name = "tabPage1";
            this.tabPage1.Size = new System.Drawing.Size(1129, 820);
            this.tabPage1.TabIndex = 0;
            this.tabPage1.Text = "Simulation";
            // 
            // groupBox1
            // 
            this.groupBox1.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.groupBox1.Controls.Add(this.chbLoopRemoval);
            this.groupBox1.Controls.Add(this.btnResetPHTables);
            this.groupBox1.Controls.Add(this.label12);
            this.groupBox1.Controls.Add(this.lbNodes);
            this.groupBox1.Controls.Add(this.chbReturnUponConnection);
            this.groupBox1.Controls.Add(this.label11);
            this.groupBox1.Controls.Add(this.label10);
            this.groupBox1.Controls.Add(this.FailedCalls);
            this.groupBox1.Controls.Add(this.label9);
            this.groupBox1.Controls.Add(this.txtCallDuration);
            this.groupBox1.Controls.Add(this.chbIO);
            this.groupBox1.Controls.Add(this.label8);
            this.groupBox1.Controls.Add(this.label7);
            this.groupBox1.Controls.Add(this.label6);
            this.groupBox1.Controls.Add(this.label5);
            this.groupBox1.Controls.Add(this.label4);
            this.groupBox1.Controls.Add(this.label3);
            this.groupBox1.Controls.Add(this.txtNodeCapacity);
            this.groupBox1.Controls.Add(this.label2);
            this.groupBox1.Controls.Add(this.txtConcurrentCalls);
            this.groupBox1.Controls.Add(this.label1);
            this.groupBox1.Controls.Add(this.txtTotalConnections);
            this.groupBox1.Controls.Add(this.lblTotalCalls);
            this.groupBox1.Controls.Add(this.lblAverage);
            this.groupBox1.Controls.Add(this.cmbSpeed);
            this.groupBox1.Controls.Add(this.cmbAlgorithm);
            this.groupBox1.Controls.Add(this.btnStart);
            this.groupBox1.Location = new System.Drawing.Point(881, 16);
            this.groupBox1.Name = "groupBox1";
            this.groupBox1.Size = new System.Drawing.Size(240, 798);
            this.groupBox1.TabIndex = 2;
            this.groupBox1.TabStop = false;
            // 
            // chbLoopRemoval
            // 
            this.chbLoopRemoval.Checked = true;
            this.chbLoopRemoval.CheckState = System.Windows.Forms.CheckState.Checked;
            this.chbLoopRemoval.Font = new System.Drawing.Font("Palatino Linotype", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.chbLoopRemoval.Location = new System.Drawing.Point(11, 262);
            this.chbLoopRemoval.Name = "chbLoopRemoval";
            this.chbLoopRemoval.RightToLeft = System.Windows.Forms.RightToLeft.Yes;
            this.chbLoopRemoval.Size = new System.Drawing.Size(184, 26);
            this.chbLoopRemoval.TabIndex = 33;
            this.chbLoopRemoval.Text = "Remove Loops";
            // 
            // btnResetPHTables
            // 
            this.btnResetPHTables.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.btnResetPHTables.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnResetPHTables.Location = new System.Drawing.Point(126, 769);
            this.btnResetPHTables.Name = "btnResetPHTables";
            this.btnResetPHTables.Size = new System.Drawing.Size(75, 23);
            this.btnResetPHTables.TabIndex = 32;
            this.btnResetPHTables.Text = "Reset Tables";
            this.btnResetPHTables.Click += new System.EventHandler(this.btnResetPHTables_Click);
            // 
            // label12
            // 
            this.label12.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label12.Location = new System.Drawing.Point(40, 298);
            this.label12.Name = "label12";
            this.label12.Size = new System.Drawing.Size(128, 16);
            this.label12.TabIndex = 31;
            this.label12.Text = "Dont route traffic";
            // 
            // lbNodes
            // 
            this.lbNodes.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.lbNodes.CheckOnClick = true;
            this.lbNodes.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lbNodes.Location = new System.Drawing.Point(11, 326);
            this.lbNodes.Name = "lbNodes";
            this.lbNodes.Size = new System.Drawing.Size(216, 304);
            this.lbNodes.TabIndex = 30;
            // 
            // chbReturnUponConnection
            // 
            this.chbReturnUponConnection.Checked = true;
            this.chbReturnUponConnection.CheckState = System.Windows.Forms.CheckState.Checked;
            this.chbReturnUponConnection.Location = new System.Drawing.Point(144, 266);
            this.chbReturnUponConnection.Name = "chbReturnUponConnection";
            this.chbReturnUponConnection.Size = new System.Drawing.Size(16, 16);
            this.chbReturnUponConnection.TabIndex = 28;
            // 
            // label11
            // 
            this.label11.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label11.Location = new System.Drawing.Point(40, 267);
            this.label11.Name = "label11";
            this.label11.Size = new System.Drawing.Size(128, 16);
            this.label11.TabIndex = 27;
            this.label11.Text = "Return upon connection";
            // 
            // label10
            // 
            this.label10.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
            this.label10.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label10.Location = new System.Drawing.Point(8, 731);
            this.label10.Name = "label10";
            this.label10.Size = new System.Drawing.Size(98, 26);
            this.label10.TabIndex = 24;
            this.label10.Text = "Failed Calls";
            // 
            // FailedCalls
            // 
            this.FailedCalls.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
            this.FailedCalls.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.FailedCalls.Location = new System.Drawing.Point(127, 726);
            this.FailedCalls.Name = "FailedCalls";
            this.FailedCalls.Size = new System.Drawing.Size(100, 23);
            this.FailedCalls.TabIndex = 25;
            // 
            // label9
            // 
            this.label9.Font = new System.Drawing.Font("Palatino Linotype", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label9.Location = new System.Drawing.Point(11, 184);
            this.label9.Name = "label9";
            this.label9.Size = new System.Drawing.Size(122, 24);
            this.label9.TabIndex = 22;
            this.label9.Text = "Call Duration";
            // 
            // txtCallDuration
            // 
            this.txtCallDuration.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtCallDuration.Location = new System.Drawing.Point(144, 184);
            this.txtCallDuration.MaxLength = 3;
            this.txtCallDuration.Name = "txtCallDuration";
            this.txtCallDuration.Size = new System.Drawing.Size(48, 22);
            this.txtCallDuration.TabIndex = 21;
            this.txtCallDuration.Text = "170";
            // 
            // chbIO
            // 
            this.chbIO.Checked = true;
            this.chbIO.CheckState = System.Windows.Forms.CheckState.Checked;
            this.chbIO.Location = new System.Drawing.Point(174, 216);
            this.chbIO.Name = "chbIO";
            this.chbIO.Size = new System.Drawing.Size(16, 16);
            this.chbIO.TabIndex = 20;
            // 
            // label8
            // 
            this.label8.Font = new System.Drawing.Font("Palatino Linotype", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label8.Location = new System.Drawing.Point(11, 216);
            this.label8.Name = "label8";
            this.label8.Size = new System.Drawing.Size(151, 16);
            this.label8.TabIndex = 19;
            this.label8.Text = "Reduce I/O for speed";
            // 
            // label7
            // 
            this.label7.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
            this.label7.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label7.Location = new System.Drawing.Point(8, 702);
            this.label7.Name = "label7";
            this.label7.Size = new System.Drawing.Size(113, 24);
            this.label7.TabIndex = 18;
            this.label7.Text = "Total Calls Made";
            // 
            // label6
            // 
            this.label6.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
            this.label6.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label6.Location = new System.Drawing.Point(8, 670);
            this.label6.Name = "label6";
            this.label6.Size = new System.Drawing.Size(113, 24);
            this.label6.TabIndex = 17;
            this.label6.Text = "Current Average";
            // 
            // label5
            // 
            this.label5.Font = new System.Drawing.Font("Palatino Linotype", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label5.Location = new System.Drawing.Point(11, 56);
            this.label5.Name = "label5";
            this.label5.Size = new System.Drawing.Size(119, 24);
            this.label5.TabIndex = 16;
            this.label5.Text = "Simulation Speed";
            // 
            // label4
            // 
            this.label4.Font = new System.Drawing.Font("Palatino Linotype", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label4.Location = new System.Drawing.Point(11, 24);
            this.label4.Name = "label4";
            this.label4.Size = new System.Drawing.Size(125, 24);
            this.label4.TabIndex = 15;
            this.label4.Text = "Mode";
            // 
            // label3
            // 
            this.label3.Font = new System.Drawing.Font("Palatino Linotype", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label3.Location = new System.Drawing.Point(11, 152);
            this.label3.Name = "label3";
            this.label3.Size = new System.Drawing.Size(122, 24);
            this.label3.TabIndex = 14;
            this.label3.Text = "Node Capacity";
            // 
            // txtNodeCapacity
            // 
            this.txtNodeCapacity.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtNodeCapacity.Location = new System.Drawing.Point(144, 152);
            this.txtNodeCapacity.MaxLength = 3;
            this.txtNodeCapacity.Name = "txtNodeCapacity";
            this.txtNodeCapacity.Size = new System.Drawing.Size(48, 22);
            this.txtNodeCapacity.TabIndex = 13;
            this.txtNodeCapacity.Text = "40";
            // 
            // label2
            // 
            this.label2.Font = new System.Drawing.Font("Palatino Linotype", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label2.Location = new System.Drawing.Point(11, 118);
            this.label2.Name = "label2";
            this.label2.Size = new System.Drawing.Size(119, 24);
            this.label2.TabIndex = 12;
            this.label2.Text = "Concurrent  Calls";
            // 
            // txtConcurrentCalls
            // 
            this.txtConcurrentCalls.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtConcurrentCalls.Location = new System.Drawing.Point(144, 120);
            this.txtConcurrentCalls.MaxLength = 3;
            this.txtConcurrentCalls.Name = "txtConcurrentCalls";
            this.txtConcurrentCalls.Size = new System.Drawing.Size(48, 22);
            this.txtConcurrentCalls.TabIndex = 11;
            this.txtConcurrentCalls.Text = "60";
            // 
            // label1
            // 
            this.label1.Font = new System.Drawing.Font("Palatino Linotype", 9F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.label1.Location = new System.Drawing.Point(11, 88);
            this.label1.Name = "label1";
            this.label1.Size = new System.Drawing.Size(90, 24);
            this.label1.TabIndex = 10;
            this.label1.Text = "Total Calls";
            // 
            // txtTotalConnections
            // 
            this.txtTotalConnections.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.txtTotalConnections.Location = new System.Drawing.Point(144, 88);
            this.txtTotalConnections.MaxLength = 6;
            this.txtTotalConnections.Name = "txtTotalConnections";
            this.txtTotalConnections.Size = new System.Drawing.Size(48, 22);
            this.txtTotalConnections.TabIndex = 9;
            this.txtTotalConnections.Text = "100";
            // 
            // lblTotalCalls
            // 
            this.lblTotalCalls.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
            this.lblTotalCalls.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblTotalCalls.Location = new System.Drawing.Point(127, 702);
            this.lblTotalCalls.Name = "lblTotalCalls";
            this.lblTotalCalls.Size = new System.Drawing.Size(80, 24);
            this.lblTotalCalls.TabIndex = 8;
            // 
            // lblAverage
            // 
            this.lblAverage.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Right)));
            this.lblAverage.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.lblAverage.Location = new System.Drawing.Point(127, 670);
            this.lblAverage.Name = "lblAverage";
            this.lblAverage.Size = new System.Drawing.Size(100, 24);
            this.lblAverage.TabIndex = 7;
            // 
            // cmbSpeed
            // 
            this.cmbSpeed.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.cmbSpeed.Items.AddRange(new object[] {
            "x 1",
            "x 5",
            "x 10",
            "x 50",
            "x 100",
            "x 1000"});
            this.cmbSpeed.Location = new System.Drawing.Point(144, 56);
            this.cmbSpeed.Name = "cmbSpeed";
            this.cmbSpeed.Size = new System.Drawing.Size(80, 24);
            this.cmbSpeed.TabIndex = 5;
            // 
            // cmbAlgorithm
            // 
            this.cmbAlgorithm.Font = new System.Drawing.Font("Palatino Linotype", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.cmbAlgorithm.Items.AddRange(new object[] {
            "On",
            "Off"});
            this.cmbAlgorithm.Location = new System.Drawing.Point(144, 24);
            this.cmbAlgorithm.Name = "cmbAlgorithm";
            this.cmbAlgorithm.Size = new System.Drawing.Size(80, 24);
            this.cmbAlgorithm.TabIndex = 4;
            // 
            // btnStart
            // 
            this.btnStart.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.btnStart.Font = new System.Drawing.Font("Palatino Linotype", 9.75F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.btnStart.Location = new System.Drawing.Point(29, 769);
            this.btnStart.Name = "btnStart";
            this.btnStart.Size = new System.Drawing.Size(75, 23);
            this.btnStart.TabIndex = 2;
            this.btnStart.Text = "Start";
            this.btnStart.Click += new System.EventHandler(this.btnStart_Click);
            // 
            // pnlGraph
            // 
            this.pnlGraph.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.pnlGraph.BackColor = System.Drawing.Color.White;
            this.pnlGraph.Location = new System.Drawing.Point(8, 8);
            this.pnlGraph.Name = "pnlGraph";
            this.pnlGraph.Size = new System.Drawing.Size(865, 806);
            this.pnlGraph.TabIndex = 1;
            // 
            // tabPage2
            // 
            this.tabPage2.BackColor = System.Drawing.Color.White;
            this.tabPage2.Controls.Add(this.pictureBox2);
            this.tabPage2.Controls.Add(this.groupBox2);
            this.tabPage2.Controls.Add(this.TheChart);
            this.tabPage2.Location = new System.Drawing.Point(4, 25);
            this.tabPage2.Name = "tabPage2";
            this.tabPage2.Size = new System.Drawing.Size(1129, 820);
            this.tabPage2.TabIndex = 1;
            this.tabPage2.Text = "Graphing";
            // 
            // pictureBox2
            // 
            this.pictureBox2.Anchor = System.Windows.Forms.AnchorStyles.Left;
            this.pictureBox2.BackColor = System.Drawing.Color.White;
            this.pictureBox2.Image = ((System.Drawing.Image)(resources.GetObject("pictureBox2.Image")));
            this.pictureBox2.Location = new System.Drawing.Point(8, 247);
            this.pictureBox2.Name = "pictureBox2";
            this.pictureBox2.Size = new System.Drawing.Size(24, 144);
            this.pictureBox2.TabIndex = 3;
            this.pictureBox2.TabStop = false;
            // 
            // groupBox2
            // 
            this.groupBox2.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.groupBox2.Controls.Add(this.btnGenerate);
            this.groupBox2.Location = new System.Drawing.Point(1007, 8);
            this.groupBox2.Name = "groupBox2";
            this.groupBox2.Size = new System.Drawing.Size(119, 685);
            this.groupBox2.TabIndex = 1;
            this.groupBox2.TabStop = false;
            // 
            // btnGenerate
            // 
            this.btnGenerate.Location = new System.Drawing.Point(8, 16);
            this.btnGenerate.Name = "btnGenerate";
            this.btnGenerate.Size = new System.Drawing.Size(96, 32);
            this.btnGenerate.TabIndex = 0;
            this.btnGenerate.Text = "Average Hops";
            this.btnGenerate.Click += new System.EventHandler(this.btnGenerate_Click);
            // 
            // TheChart
            // 
            this.TheChart.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.TheChart.Application = "";
            this.TheChart.ApplicationDNC = "";
            this.TheChart.Background.Color = System.Drawing.Color.White;
            background1.Color = System.Drawing.Color.FromArgb(((int)(((byte)(232)))), ((int)(((byte)(235)))), ((int)(((byte)(238)))));
            chartArea1.Background = background1;
            subValue1.Line = line1;
            element1.DefaultSubValue = subValue1;
            element1.Hotspot = hotspot1;
            legendEntry1.Background = background2;
            line2.Color = System.Drawing.Color.Empty;
            legendEntry1.DividerLine = line2;
            legendEntry1.Hotspot = hotspot2;
            element1.LegendEntry = legendEntry1;
            element1.XAxisTick = null;
            element1.YAxisTick = null;
            chartArea1.DefaultElement = element1;
            line3.Color = System.Drawing.Color.LightGray;
            chartArea1.InteriorLine = line3;
            label14.Font = new System.Drawing.Font("Tahoma", 8F);
            label14.Hotspot = hotspot3;
            label14.Truncation = truncation1;
            chartArea1.Label = label14;
            background3.Color = System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(219)))));
            legendBox1.Background = background3;
            legendBox1.CornerBottomRight = dotnetCHARTING.WinForms.BoxCorner.Cut;
            legendEntry2.Background = background4;
            line4.Color = System.Drawing.Color.Empty;
            legendEntry2.DividerLine = line4;
            legendEntry2.Hotspot = hotspot4;
            label15.Hotspot = hotspot5;
            label15.Truncation = truncation2;
            legendEntry2.LabelStyle = label15;
            legendBox1.DefaultEntry = legendEntry2;
            legendEntry3.Background = background5;
            line5.Color = System.Drawing.Color.Gray;
            legendEntry3.DividerLine = line5;
            legendEntry3.Hotspot = hotspot6;
            legendEntry3.Name = "Name";
            legendEntry3.SortOrder = -1;
            legendEntry3.Value = "Value";
            legendEntry3.Visible = false;
            legendBox1.HeaderEntry = legendEntry3;
            line6.Color = System.Drawing.Color.FromArgb(((int)(((byte)(70)))), ((int)(((byte)(128)))), ((int)(((byte)(128)))), ((int)(((byte)(128)))));
            legendBox1.InteriorLine = line6;
            legendBox1.LabelStyle = label15;
            line7.Color = System.Drawing.Color.Gray;
            legendBox1.Line = line7;
            legendBox1.Padding = 4;
            legendBox1.Position = null;
            legendBox1.Shadow = shadow1;
            legendBox1.Visible = true;
            chartArea1.LegendBox = legendBox1;
            line8.Color = System.Drawing.Color.Gray;
            chartArea1.Line = line8;
            chartArea1.Shadow = shadow2;
            chartArea1.StartDateOfYear = new System.DateTime(((long)(0)));
            background6.Color = System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(219)))));
            box1.Background = background6;
            line9.Color = System.Drawing.Color.FromArgb(((int)(((byte)(70)))), ((int)(((byte)(128)))), ((int)(((byte)(128)))), ((int)(((byte)(128)))));
            box1.InteriorLine = line9;
            label16.Color = System.Drawing.Color.FromArgb(((int)(((byte)(97)))), ((int)(((byte)(45)))), ((int)(((byte)(38)))));
            label16.Font = new System.Drawing.Font("Tahoma", 8F, System.Drawing.FontStyle.Bold);
            label16.Hotspot = hotspot7;
            label16.Truncation = truncation3;
            box1.Label = label16;
            line10.Color = System.Drawing.Color.Gray;
            box1.Line = line10;
            box1.Position = null;
            box1.Shadow = shadow3;
            box1.Visible = true;
            chartArea1.TitleBox = box1;
            this.TheChart.ChartArea = chartArea1;
            this.TheChart.Controls.Add(this.label13);
            this.TheChart.Controls.Add(this.pictureBox1);
            this.TheChart.Controls.Add(this.panel2);
            this.TheChart.DataGrid = null;
            axis1.CombinedElementsCalculation = dotnetCHARTING.WinForms.Calculation.Sum;
            line11.Color = System.Drawing.Color.LightGray;
            axisTick1.GridLine = line11;
            line12.Length = 3;
            axisTick1.Line = line12;
            axisTick1.ValueLow = double.NaN;
            axis1.DefaultTick = axisTick1;
            axis1.LabelMarker = null;
            axis1.LogarithmicBase = 10;
            axis1.OverlappingCircularLabelSeparator = " & ";
            axis1.RadarMode = dotnetCHARTING.WinForms.RadarMode.Spider;
            axis1.ScaleBreakStyle = dotnetCHARTING.WinForms.ScaleBreakStyle.ZigZag;
            scaleRange1.ValueLow = double.NaN;
            axis1.ScaleRange = scaleRange1;
            axis1.TickLabelAngle = 45F;
            axis1.TickLabelSeparatorLine = line13;
            line14.Color = System.Drawing.Color.Red;
            axisTick2.GridLine = line14;
            line15.Length = 3;
            axisTick2.Line = line15;
            axisTick2.ValueLow = double.NaN;
            axis1.ZeroTick = axisTick2;
            this.TheChart.DefaultAxis = axis1;
            this.TheChart.DefaultCultureName = "";
            line16.Color = System.Drawing.Color.FromArgb(((int)(((byte)(93)))), ((int)(((byte)(28)))), ((int)(((byte)(59)))));
            subValue2.Line = line16;
            element2.DefaultSubValue = subValue2;
            element2.Hotspot = hotspot8;
            legendEntry4.Background = background7;
            line17.Color = System.Drawing.Color.Empty;
            legendEntry4.DividerLine = line17;
            legendEntry4.Hotspot = hotspot9;
            element2.LegendEntry = legendEntry4;
            smartLabel1.Color = System.Drawing.Color.Empty;
            smartLabel1.Hotspot = hotspot10;
            smartLabel1.Line = line18;
            smartLabel1.Truncation = truncation4;
            element2.SmartLabel = smartLabel1;
            element2.XAxisTick = null;
            element2.YAxisTick = null;
            this.TheChart.DefaultElement = element2;
            this.TheChart.DefaultShadow = shadow4;
            this.TheChart.Location = new System.Drawing.Point(22, 8);
            this.TheChart.Mapping.DefaultShape.Background = background8;
            label17.Hotspot = hotspot11;
            label17.Truncation = truncation5;
            this.TheChart.Mapping.DefaultShape.Label = label17;
            this.TheChart.Mapping.DefaultShape.Line = line19;
            this.TheChart.Mapping.DefaultShape.Marker = elementMarker1;
            this.TheChart.Name = "TheChart";
            this.TheChart.NoDataLabel.Hotspot = hotspot12;
            this.TheChart.NoDataLabel.Text = "No Data";
            this.TheChart.NoDataLabel.Truncation = truncation6;
            this.TheChart.Palette = new System.Drawing.Color[] {
        System.Drawing.Color.FromArgb(((int)(((byte)(156)))), ((int)(((byte)(154)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(156)))), ((int)(((byte)(48)))), ((int)(((byte)(99))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(206))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(206)))), ((int)(((byte)(255)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(99)))), ((int)(((byte)(0)))), ((int)(((byte)(99))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(130)))), ((int)(((byte)(132))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(101)))), ((int)(((byte)(206))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(206)))), ((int)(((byte)(207)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(0)))), ((int)(((byte)(132))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(0)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(255)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(132)))), ((int)(((byte)(0)))), ((int)(((byte)(132))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(132)))), ((int)(((byte)(0)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(130)))), ((int)(((byte)(132))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(0)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(207)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(206)))), ((int)(((byte)(255)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(206)))), ((int)(((byte)(255)))), ((int)(((byte)(206))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(156))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(156)))), ((int)(((byte)(207)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(154)))), ((int)(((byte)(206))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(206)))), ((int)(((byte)(154)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(207)))), ((int)(((byte)(156))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(49)))), ((int)(((byte)(101)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(49)))), ((int)(((byte)(207)))), ((int)(((byte)(206))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(156)))), ((int)(((byte)(207)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(207)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(154)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(101)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(99)))), ((int)(((byte)(101)))), ((int)(((byte)(156))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(148)))), ((int)(((byte)(150)))), ((int)(((byte)(148))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(48)))), ((int)(((byte)(99))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(49)))), ((int)(((byte)(154)))), ((int)(((byte)(99))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(48)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(49)))), ((int)(((byte)(48)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(156)))), ((int)(((byte)(48)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(156)))), ((int)(((byte)(48)))), ((int)(((byte)(99))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(49)))), ((int)(((byte)(48)))), ((int)(((byte)(156))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(49)))), ((int)(((byte)(48)))), ((int)(((byte)(49))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(0)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(0)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(255)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(0)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(0)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(255)))), ((int)(((byte)(255))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(132)))), ((int)(((byte)(0)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(130)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(0)))), ((int)(((byte)(132))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(132)))), ((int)(((byte)(130)))), ((int)(((byte)(0))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(132)))), ((int)(((byte)(0)))), ((int)(((byte)(132))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(0)))), ((int)(((byte)(130)))), ((int)(((byte)(132))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(198)))), ((int)(((byte)(195)))), ((int)(((byte)(198))))),
        System.Drawing.Color.FromArgb(((int)(((byte)(132)))), ((int)(((byte)(130)))), ((int)(((byte)(132)))))};
            this.TheChart.ShadingEffectMode = dotnetCHARTING.WinForms.ShadingEffectMode.Three;
            this.TheChart.ShowDateInTitle = false;
            this.TheChart.Size = new System.Drawing.Size(624, 685);
            this.TheChart.SmartLabelLine = line18;
            this.TheChart.SmartPaletteAutoSync = false;
            this.TheChart.StartDateOfYear = new System.DateTime(((long)(0)));
            this.TheChart.TabIndex = 0;
            this.TheChart.TempDirectory = "C:\\DOCUME~1\\Lawrence\\LOCALS~1\\Temp\\";
            this.TheChart.ToolTipTemplate = "";
            this.TheChart.Type = dotnetCHARTING.WinForms.ChartType.Scatter;
            background9.Color = System.Drawing.Color.FromArgb(((int)(((byte)(232)))), ((int)(((byte)(235)))), ((int)(((byte)(238)))));
            chartArea2.Background = background9;
            subValue3.Line = line20;
            element3.DefaultSubValue = subValue3;
            element3.Hotspot = hotspot13;
            legendEntry5.Background = background10;
            line21.Color = System.Drawing.Color.Empty;
            legendEntry5.DividerLine = line21;
            legendEntry5.Hotspot = hotspot14;
            element3.LegendEntry = legendEntry5;
            element3.XAxisTick = null;
            element3.YAxisTick = null;
            chartArea2.DefaultElement = element3;
            line22.Color = System.Drawing.Color.LightGray;
            chartArea2.InteriorLine = line22;
            label18.Font = new System.Drawing.Font("Tahoma", 8F);
            label18.Hotspot = hotspot15;
            label18.Truncation = truncation7;
            chartArea2.Label = label18;
            chartArea2.LegendBox = null;
            line23.Color = System.Drawing.Color.Gray;
            chartArea2.Line = line23;
            chartArea2.Shadow = shadow5;
            chartArea2.StartDateOfYear = new System.DateTime(((long)(0)));
            background11.Color = System.Drawing.Color.FromArgb(((int)(((byte)(255)))), ((int)(((byte)(255)))), ((int)(((byte)(219)))));
            box2.Background = background11;
            line24.Color = System.Drawing.Color.FromArgb(((int)(((byte)(70)))), ((int)(((byte)(128)))), ((int)(((byte)(128)))), ((int)(((byte)(128)))));
            box2.InteriorLine = line24;
            label19.Color = System.Drawing.Color.FromArgb(((int)(((byte)(97)))), ((int)(((byte)(45)))), ((int)(((byte)(38)))));
            label19.Font = new System.Drawing.Font("Tahoma", 8F, System.Drawing.FontStyle.Bold);
            label19.Hotspot = hotspot16;
            label19.Truncation = truncation8;
            box2.Label = label19;
            line25.Color = System.Drawing.Color.Gray;
            box2.Line = line25;
            box2.Position = null;
            box2.Shadow = shadow6;
            box2.Visible = true;
            chartArea2.TitleBox = box2;
            this.TheChart.VolumeArea = chartArea2;
            // 
            // label13
            // 
            this.label13.Location = new System.Drawing.Point(0, 0);
            this.label13.Name = "label13";
            this.label13.Size = new System.Drawing.Size(979, 82);
            this.label13.TabIndex = 2;
            this.label13.Text = ".";
            // 
            // pictureBox1
            // 
            this.pictureBox1.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.pictureBox1.BackColor = System.Drawing.Color.White;
            this.pictureBox1.Image = ((System.Drawing.Image)(resources.GetObject("pictureBox1.Image")));
            this.pictureBox1.Location = new System.Drawing.Point(240, 657);
            this.pictureBox1.Name = "pictureBox1";
            this.pictureBox1.Size = new System.Drawing.Size(144, 24);
            this.pictureBox1.TabIndex = 0;
            this.pictureBox1.TabStop = false;
            // 
            // panel2
            // 
            this.panel2.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Bottom | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.panel2.BackColor = System.Drawing.Color.White;
            this.panel2.Location = new System.Drawing.Point(0, 669);
            this.panel2.Name = "panel2";
            this.panel2.Size = new System.Drawing.Size(624, 16);
            this.panel2.TabIndex = 1;
            // 
            // MainForm
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
            this.ClientSize = new System.Drawing.Size(1153, 878);
            this.Controls.Add(this.tabControl1);
            this.Name = "MainForm";
            this.Text = "Rate Allocation Simulator";
            this.WindowState = System.Windows.Forms.FormWindowState.Maximized;
            this.Load += new System.EventHandler(this.MainForm_Load);
            this.tabControl1.ResumeLayout(false);
            this.tabPage1.ResumeLayout(false);
            this.groupBox1.ResumeLayout(false);
            this.groupBox1.PerformLayout();
            this.tabPage2.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox2)).EndInit();
            this.groupBox2.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.TheChart)).EndInit();
            this.TheChart.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.pictureBox1)).EndInit();
            this.ResumeLayout(false);

		}

		#endregion

        private void MainForm_Load(object sender, EventArgs e)
        {

        }

        
	}
}