using System;
using System.Collections;
using System.Drawing;

namespace RateAllocation
{
	/// <summary>
	/// The Node class represents node on the network and holds phermone tables
	/// which can be called to determine the best route to a destination node.
	/// </summary>
	public class Node
	{
		#region Properties

		// the id of the node
		public int ID;
		// the ids of all the connected nodes
		public int[] Connections;	
		// the call capacity of the node
		public int Capacity=Global.NodeCapacity;
		// the ids of all the calls currently placed on the node
		public ArrayList CallIDS=new ArrayList();
		// a pheromone table for every other node in the network
		public PheromoneTable[] PheromoneTable;
		// when set to false the node will only accept traffic as a final desination node
		// and will refuse to route any traffic
		public bool DontRouteTraffic=false;
		// the point on screen in which to render the node
		private Point coordinates;

		/// <summary>
		/// The centre pixels of the node (Actual coordinates * Scale)
		/// </summary>
		public Point Centroid
		{
			get	{return new Point(Convert.ToInt32(coordinates.X*Global.Scale), Convert.ToInt32(coordinates.Y*Global.Scale) );}
		}

		/// <summary>
		/// Actual coordinates of the Node
		/// </summary>
		public Point Coordinates
		{
			get	{return new Point(Convert.ToInt32(coordinates.X*Global.Scale), Convert.ToInt32(coordinates.Y*Global.Scale) );}
			set{this.coordinates=value;}
		}

		/// <summary>
		/// returns true if the network is full or Traffic Routing has been disabled
		/// </summary>
		public bool FullCapacity
		{
			get
			{
				// if DontRouteTraffic is set to true then pretend it is full capacity and
				// refuse connection
				if(DontRouteTraffic)
					return false;
				else // oherwise make sure capacity hasnt been reached
					return (bool)(Global.NodeCapacity<=CallIDS.Count);
			}
		}

		#endregion

		
		public Node(int id)
		{
			this.ID = id;
		}

		
		public PheromoneTable GetPheromoneTableForNode(int nodeid)
		{
			for(int i=0;i<PheromoneTable.Length;i++)
			{
				
				if(PheromoneTable[i].NodeID==nodeid)
					return PheromoneTable[i];
			}
			
			
			return null;
		}


	
		public void GenerateDefaultPheromoneTables()
		{
			
			this.PheromoneTable = new PheromoneTable[Global.Nodes.Length-1];

			int index=0;

		
			for(int i=0;i<Global.Nodes.Length;i++)
			{
				
				if(Global.Nodes[i].ID!=this.ID)
				{
					this.PheromoneTable[index++] = new PheromoneTable(Global.Nodes[i], this.Connections);
				}
			}
		}


		
		public static bool Connect(int nodeid, int callid, int DestinationNodeID)
		{
			Node n = Global.Nodes[nodeid];

			if( !n.FullCapacity && (!n.DontRouteTraffic || DestinationNodeID==n.ID))
			{
				
				n.CallIDS.Add(callid);

			
				return true;
			}

		
			return false;
		}


		
		public override string ToString()
		{
			return "Node "+this.ID.ToString();
		}

	}
}